
/* 
 * Copyright (c) 1993-2005 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/


#ifndef viam_TCLSERV_CLIENT_ERROR_H
#define viam_TCLSERV_CLIENT_ERROR_H

#include <server/viamError.h>

/* -- MODULES ERRORS -------------------------------------------------- */

enum viam_error {
	E_viam_OK					  			= 0,

	/* module errors */
	E_viam_UNSUPPORTED_HWMODE             = S_viam_UNSUPPORTED_HWMODE,
	E_viam_NO_SUCH_FILTER                 = S_viam_NO_SUCH_FILTER,
	E_viam_NOT_IMPLEMENTED                = S_viam_NOT_IMPLEMENTED,
	E_viam_INVALID_VALUE                  = S_viam_INVALID_VALUE,
	E_viam_NO_SUCH_IMAGE                  = S_viam_NO_SUCH_IMAGE,
	E_viam_NO_SUCH_CAMERA                 = S_viam_NO_SUCH_CAMERA,
	E_viam_NO_SUCH_BANK                   = S_viam_NO_SUCH_BANK,
	E_viam_BAD_ID                         = S_viam_BAD_ID,
	E_viam_MEMORY                         = S_viam_MEMORY,
	E_viam_MODULE_RUNNING                 = S_viam_MODULE_RUNNING,
	E_viam_DUPLICATE_ID                   = S_viam_DUPLICATE_ID,
	E_viam_NO_SUCH_DEVICE                 = S_viam_NO_SUCH_DEVICE,
	E_viam_FILE_IO                        = S_viam_FILE_IO,
	E_viam_NOT_CALIBRATED                 = S_viam_NOT_CALIBRATED,
	E_viam_CALIBRATING                    = S_viam_CALIBRATING,
	E_viam_FEATURE_DISABLED               = S_viam_FEATURE_DISABLED,
	E_viam_OPENCV                         = S_viam_OPENCV,
	E_viam_BAD_IMAGE_COUNT                = S_viam_BAD_IMAGE_COUNT,
	E_viam_IMAGE_GEOMETRY                 = S_viam_IMAGE_GEOMETRY,
	E_viam_NOT_CONFIGURED                 = S_viam_NOT_CONFIGURED,
	E_viam_ARRAY_SIZE                     = S_viam_ARRAY_SIZE,
	E_viam_NO_SUCH_POM_FRAME              = S_viam_NO_SUCH_POM_FRAME,
	E_viam_UNKNOWN_ERROR                  = S_viam_UNKNOWN_ERROR,
	E_viam_NO_CAMERA                      = S_viam_NO_CAMERA,
	E_viam_CONFIGURED                     = S_viam_CONFIGURED,
	E_viam_FWBUS                          = S_viam_FWBUS,
	E_viam_NO_DISPLAY_THREAD              = S_viam_NO_DISPLAY_THREAD,


	/* std errors */
	E_viam_ACTIVITY_INTERRUPTED           = S_viam_stdGenoM_ACTIVITY_INTERRUPTED,
	E_viam_TOO_MANY_ACTIVITIES            = S_viam_stdGenoM_TOO_MANY_ACTIVITIES,
	E_viam_ACTIVITY_FAILED                = S_viam_stdGenoM_ACTIVITY_FAILED,
	E_viam_WAIT_ABORT_ZOMBIE_ACTIVITY     = S_viam_stdGenoM_WAIT_ABORT_ZOMBIE_ACTIVITY,
	E_viam_UNKNOWN_ACTIVITY               = S_viam_stdGenoM_UNKNOWN_ACTIVITY,
	E_viam_FORBIDDEN_ACTIVITY_TRANSITION  = S_viam_stdGenoM_FORBIDDEN_ACTIVITY_TRANSITION,
	E_viam_SYSTEM_ERROR                   = S_viam_stdGenoM_SYSTEM_ERROR,
	E_viam_ACTIVITY_ALREADY_ENDED         = S_viam_stdGenoM_ACTIVITY_ALREADY_ENDED,
	E_viam_WAIT_INIT_RQST                 = S_viam_stdGenoM_WAIT_INIT_RQST,
	E_viam_CONTROL_CODEL_ERROR            = S_viam_stdGenoM_CONTROL_CODEL_ERROR,
	E_viam_EXEC_TASK_SUSPENDED            = S_viam_stdGenoM_EXEC_TASK_SUSPENDED,
	E_viam_BAD_BLOCK_TYPE                 = S_viam_stdGenoM_BAD_BLOCK_TYPE,
	E_viam_BAD_POSTER_TYPE                = S_viam_stdGenoM_BAD_POSTER_TYPE,

};

typedef enum viam_error viam_error_t;

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Take an error string in parameter, and try to get the error index associated
 * to this string
 * Returns -1 in failure case (and err is not set)
 * Returns 0 in success case (and err has a sensitive value)
 */
int viam_decode_error(const char* str, int *err);

/*
 * Take an integer representing an error, and try to get its textual
 * representation, in the viam context.
 *
 * Returns NULL in case of failure
 */
const char* viam_error_str(int err);

#ifdef __cplusplus
}
#endif


/*-------------------------- end file loading ---------------------------*/
#endif
